pub enum DirectionType {
Face,
Vertex,
}Expand description
A flag that can be used to indicate whether we are referencing directions for the face or a vertex of a grid cell.
Variants
Face
A direction that is aligned with the faces of a grid cell.
Vertex
A direction that is aligned with the vertices of a grid cell.