This crate provides a “dynamic” coordinate that dispatches to one
of the other concrete coordinate types. This is useful when
implementing code that is not only generic in the coordinate system,
but must be able to switch between them at runtime.
Color assignment values for grid coordinates. The four color theorem
proves that for any loopless planar graph no more colors are needed to
color adjacent nodes so that no two adjacent nodes have the same color.
So as long as the coordinate system is isomorphic to a loopless planar
graph, we can use just four colors provide a suitable coloring for a grid.
Should this library expand beyond such coordinate systems, this design
choice will need to be revisited.
A trait for those coordinate systems that satisfy the properties of
being an algebraic module. While not strictly required by the Coord
trait, the focus of this crate is on discrete grid systems. As such,
they will not satisfy the properties of a vector or linear space,
because their scalar multiplication is not defined for a field.